#
# spec file for package lxqt-sudo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-sudo
Version:        1.4.0
Release:        bp156.1.2
Summary:        GUI frontend for sudo
License:        LGPL-2.1-only
Group:          System/X11/Utilities
URL:            http://lxqt.org
Source:         https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.1.0
BuildRequires:  gcc-c++
BuildRequires:  lxqt-build-tools-devel >= 0.13.0
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.15.0
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(lxqt) >= %{version}
Requires:       sudo
Recommends:     %{name}-lang

%description
A graphical frontend for plain sudo (for requesting optional password in GUI
fashion).
When invoked it simply spawns child sudo process with requested command (and
arguments). If sudo requests user's password, the GUI password dialog is shown
and (after submit) the password is provided to sudo.

%lang_package

%prep
%setup -q

%build
%cmake -DPULL_TRANSLATIONS=No

%install
%cmake_install

%find_lang %{name} --with-qt

%files
%license LICENSE
%doc AUTHORS
%{_bindir}/%{name}
%{_bindir}/lxsu*
%{_bindir}/lxdoas
%{_mandir}/man?/%{name}.*
%{_mandir}/man?/lxsu*.*
%{_mandir}/man?/lxdoas*

%files lang -f %{name}.lang
%dir %{_datadir}/lxqt
%dir %{_datadir}/lxqt/translations
%{_datadir}/lxqt/translations/lxqt-sudo

%changelog
* Mon Nov  6 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0:
  * Updated translations and bumped the version.
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Added support for `doas` backend
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Updated translations and bumped the version.
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Updated translations and bumped the version.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Code: Handled what was deprecated by Qt5.15.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Code: Handled what was deprecated by Qt5.15.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Use QFlags default constructor.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lxqt-sudo.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * Fix (re-)setting HOME with sudo backend.
  * Added TERM to allowed/preserved environment variables.
  * Added NetBSD support.
* Mon Jan 27 2020 Michael Vetter <mvetter@suse.com>
- bsc#1161365: Fix build
- Add buildrequire for glib
* Mon Feb 25 2019 mvetter@suse.com
- Update to 0.14.1:
  * Dont strip XAUTHLOCALHOSTNAME, it is required for lxqt-sudo
  to function properly.
  * Updated translations
- Remove lxqt-bsc1122410-clear-env.patch: upstreamed
* Tue Feb  5 2019 mvetter@suse.com
- bsc#1122410: Dont clear XAUTHLOCALHOSTNAME
- Add lxqt-bsc1122410-clear-env.patch:
  See https://github.com/lxqt/lxqt-sudo/issues/101
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Force “C” locale for su/sudo
  * Security: Prevent malicious attempts for command injection
  * Strip environment - Leave only required environment variables (for X & locale) to get into the elevated child process.
  * Make critical error messages less obscure
  * Fixed the layout and line-break
- Remove lxqt-sudo-0.13.0-locale-env.patch: upstreamed
- Move translation from lxqt-l10n into package
* Thu Jul 26 2018 mvetter@suse.com
- bsc#1100871: Fix layout problem with CJK the usptream way
  by setting the locale to C
- Add lxqt-sudo-0.13.0-locale-env.patch
- Remove lxqt-sudo-prompt-fix.patch: Using upstream approved fix
* Thu Jul 12 2018 tiwai@suse.de
- Fix the missing capture of the prompt line without the space
  letter at the end of line (boo#1100871):
  lxqt-sudo-prompt-fix.patch
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * passworddialog.cpp: include QIcon explicitely
  * CMake: Prevent in-source builds
  * fix http -> https
  * Fixed mentions of LXDE
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set informal patch version
  * Added basic .gitattributes
  * Drops Qt5Core_VERSION_STRING
  * set Qt::AA_UseHighDpiPixmaps to true
  * Bump year
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Make CMakeLists.txt more uniform.
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Add README.md
  * build: Forward translations parameters
  * ts-files removal (#21)
  * Remove translations (will be pulled in build time)
  * Bump year
  * Italian translation update
  * Updated Russian translation Fix language and typos
  * Add Russian translation
- Add keyring
* Wed Nov  4 2015 mvetter@suse.com
- Git build was done by aaz2011@mail.ru
- Setting minimum Cmake version
* Sun Aug 23 2015 and.november@opensuse.org
- initial package for openSUSE
